Django-Yummy
############

Yummy is a recipes application based on Django framework.

Build status
************

:Master branch:

  .. image:: https://secure.travis-ci.org/SanomaCZ/django-yummy.png?branch=master
     :alt: Travis CI - Distributed build platform for the open source community
     :target: http://travis-ci.org/#!/SanomaCZ/django-yummy
